Skip to content
KernelIndex
Search⌘K

submission 470769

nvvagias · python · License unknown

Use it

Vendorable · source mirrored · license unknownView source →

No package. Vendor the mirrored source: 38 lines, June 9 Researcher Reciprocity License v1.0.

submission_triton_bandwidth.py
curl "https://kernelindex.com/api/v1/implementations/kernelbot-vectoradd-v2-470769?include=source"
interfacepython
Compatibility
measured onNVIDIA A100
declared hardwareNVIDIA A100
architecturessm_80
dtypesfp16

Benchmark evidence

1 measurement across 1 GPU, fastest first.

Operation / workload
Hardware
Latency
Rank
Observed
FP16 vector additionsuite of 5 cases
NVIDIA A100
904.6µs
#14 of 87
2026-02-05

Reported · How evidence levels are derived →

Source and license

sourceavailable
revision digestsha256:c8f1616874ec86c82e30201008f74356fe1937c02be1483fc551eea82bb0b8df
license declaredunknown
license concludedunknown
authorsnvvagias
imported2026-08-15

Kernel source

submission_triton_bandwidth.py38 lines
#!POPCORN leaderboard vectoradd_v2
#!POPCORN gpu A100

import torch
import triton
import triton.language as tl
from task import input_t, output_t


@triton.jit
def add_kernel(
    A_ptr,
    B_ptr,
    C_ptr,
    N,
    BLOCK_SIZE: tl.constexpr,
):
    pid = tl.program_id(0)
    offsets = pid * BLOCK_SIZE + tl.arange(0, BLOCK_SIZE)
    mask = offsets < N
    
    a = tl.load(A_ptr + offsets, mask=mask)
    b = tl.load(B_ptr + offsets, mask=mask)
    c = a + b
    tl.store(C_ptr + offsets, c, mask=mask)


def custom_kernel(data: input_t) -> output_t:
    A, B, C = data
    N = A.numel()
    
    BLOCK_SIZE = 4096
    grid = (triton.cdiv(N, BLOCK_SIZE),)
    
    add_kernel[grid](A, B, C, N, BLOCK_SIZE=BLOCK_SIZE)
    
    return C
scrolls · 38 lines total

Source code from GPU Mode and the KernelBot dataset · June 9 Researcher Reciprocity License v1.0

Best evidence level for this revision: reported

JSON